Task: The Stanford Natural Language Inference (SNLI) Corpus
============================================================
Description: The SNLI corpus (version 1.0) is a collection of 570k human-written English sentence pairs manually labeled for balanced classification with the labels entailment, contradiction, and neutral, supporting the task of natural language inference (NLI), also known as recognizing textual entailment (RTE). See https://nlp.stanford.edu/projects/snli/

Tags: #SNLI, #All, #Entailment

